@@ -18,8 +18,7 @@
 #include <QScrollArea>
 #include <QVBoxLayout>
 #include <QPalette>
-#include <QFile>
-#include <QProcess>
+
 
 
 
@@ -51,13 +50,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     setWindowTitle("QRadio");
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
 	
-	QFile file( "/opt/qradio/background.png" );
-    if( !file.exists() )
-      {
-       QProcess *myProcess = new QProcess;
-       myProcess->execute("echo 'ln -s /etc/hildon/theme/mediaplayer/background.png /opt/qradio/background.png' | root");
-      }
-    file.close();
+	
 
     QPalette p = palette();
     QPixmap pixmap1("/opt/qradio/background.png");
@@ -304,7 +297,7 @@ void MainWindow::manageStationsActionTriggered()
 void MainWindow::about()
 {
     QMessageBox::about(this, tr("About QRadio"),
-                tr("<h2>QRadio 0.3.3</h2>"
+                tr("<h2>QRadio 0.3.4</h2>"
                    "<p>"
                    "<p>Written by Giovanni Grammatico (ggiovanni88@yahoo.it)"));
 
